@@ -16,7 +16,7 @@ from dataclasses import dataclass
 from datetime import date
 from typing import Callable, Dict, List, Optional, cast
 
-from rp2.configuration import Configuration
+from rp2.configuration import Configuration, to_string
 from rp2.in_transaction import InTransaction
 from rp2.input_data import InputData
 from rp2.intra_transaction import IntraTransaction
@@ -69,7 +69,7 @@ class Balance:
         if extra_data:
             class_specific_data.extend(extra_data)
 
-        return self.configuration.to_string(indent=indent, repr_format=repr_format, data=class_specific_data)
+        return to_string(indent=indent, repr_format=repr_format, data=class_specific_data)
 
     def __str__(self) -> str:
         return self.to_string(indent=0, repr_format=False)
