@@ -68,7 +68,7 @@ class TestInTransaction(unittest.TestCase):
             "inTerest",
             RP2Decimal("1000.0"),
             RP2Decimal("2.0002"),
-            RP2Decimal("0"),
+            fiat_fee=RP2Decimal("0"),
             fiat_in_no_fee=RP2Decimal("2000.2"),
             fiat_in_with_fee=RP2Decimal("2000.2"),
             internal_id=19,
@@ -169,7 +169,7 @@ class TestInTransaction(unittest.TestCase):
             "BuY",
             RP2Decimal("1000"),
             RP2Decimal("2.0002"),
-            RP2Decimal("20"),
+            fiat_fee=RP2Decimal("20"),
             internal_id=19,
         )
         self.assertFalse(in_transaction.is_taxable())
@@ -208,7 +208,7 @@ class TestInTransaction(unittest.TestCase):
             "iNtErEsT",
             RP2Decimal("1000.0"),
             RP2Decimal("2.0002"),
-            RP2Decimal("0"),
+            fiat_fee=RP2Decimal("0"),
             fiat_in_no_fee=RP2Decimal("2000.2"),
             fiat_in_with_fee=RP2Decimal("2000.2"),
             internal_id=19,
@@ -222,7 +222,7 @@ class TestInTransaction(unittest.TestCase):
             "INTEReST",
             RP2Decimal("1000.0"),
             RP2Decimal("2.0002"),
-            RP2Decimal("0"),
+            fiat_fee=RP2Decimal("0"),
             fiat_in_no_fee=RP2Decimal("2000.2"),
             fiat_in_with_fee=RP2Decimal("2000.2"),
             internal_id=19,
@@ -236,7 +236,7 @@ class TestInTransaction(unittest.TestCase):
             "interest",
             RP2Decimal("1000.0"),
             RP2Decimal("2.0002"),
-            RP2Decimal("0"),
+            fiat_fee=RP2Decimal("0"),
             fiat_in_no_fee=RP2Decimal("2000.2"),
             fiat_in_with_fee=RP2Decimal("2000.2"),
             internal_id=20,
@@ -246,7 +246,7 @@ class TestInTransaction(unittest.TestCase):
         self.assertNotEqual(in_transaction, in_transaction3)
         self.assertEqual(hash(in_transaction), hash(in_transaction))
         self.assertEqual(hash(in_transaction), hash(in_transaction2))
-        # These hashes would only be equal in case of hash collision (possible but very unlikey)
+        # These hashes would only be equal in case of hash collision (possible but very unlikely)
         self.assertNotEqual(hash(in_transaction), hash(in_transaction3))
 
     def test_bad_to_string(self) -> None:
@@ -259,7 +259,7 @@ class TestInTransaction(unittest.TestCase):
             "INteREst",
             RP2Decimal("1000.0"),
             RP2Decimal("2.0002"),
-            RP2Decimal("0"),
+            fiat_fee=RP2Decimal("0"),
             fiat_in_no_fee=RP2Decimal("2000.2"),
             fiat_in_with_fee=RP2Decimal("2000.2"),
             internal_id=19,
@@ -305,7 +305,7 @@ class TestInTransaction(unittest.TestCase):
                 "interest",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -321,27 +321,11 @@ class TestInTransaction(unittest.TestCase):
                 "INTEREST",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
             )
-        with self.assertRaisesRegex(RP2ValueError, "Parameter 'internal_id' has non-positive value .*"):
-            # Bad internal_id
-            InTransaction(
-                self._configuration,
-                "2021-01-02T08:42:43.882Z",
-                "B1",
-                "BlockFi",
-                "Bob",
-                "Interest",
-                RP2Decimal("1000"),
-                RP2Decimal("2.0002"),
-                RP2Decimal("20"),
-                fiat_in_no_fee=RP2Decimal("2000.2"),
-                fiat_in_with_fee=RP2Decimal("2020.2"),
-                internal_id=-19,
-            )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'internal_id' has non-integer .*"):
             # Bad internal_id
             InTransaction(
@@ -353,7 +337,7 @@ class TestInTransaction(unittest.TestCase):
                 "buy",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id="19",  # type: ignore
@@ -369,7 +353,7 @@ class TestInTransaction(unittest.TestCase):
                 "BUY",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -385,7 +369,7 @@ class TestInTransaction(unittest.TestCase):
                 "intErest",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -401,7 +385,7 @@ class TestInTransaction(unittest.TestCase):
                 "intERest",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -417,7 +401,7 @@ class TestInTransaction(unittest.TestCase):
                 "intEResT",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -433,7 +417,7 @@ class TestInTransaction(unittest.TestCase):
                 "IntEResT",
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -449,7 +433,7 @@ class TestInTransaction(unittest.TestCase):
                 "INtEResT",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -465,7 +449,7 @@ class TestInTransaction(unittest.TestCase):
                 "INtEresT",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -481,7 +465,7 @@ class TestInTransaction(unittest.TestCase):
                 "INTEresT",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -497,7 +481,7 @@ class TestInTransaction(unittest.TestCase):
                 "iNTEresT",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -513,7 +497,7 @@ class TestInTransaction(unittest.TestCase):
                 "seLl",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -529,7 +513,7 @@ class TestInTransaction(unittest.TestCase):
                 "",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -545,7 +529,7 @@ class TestInTransaction(unittest.TestCase):
                 "cook",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -561,7 +545,7 @@ class TestInTransaction(unittest.TestCase):
                 1111,  # type: ignore
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -577,7 +561,7 @@ class TestInTransaction(unittest.TestCase):
                 "iNTErest",
                 RP2Decimal("0"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -593,7 +577,7 @@ class TestInTransaction(unittest.TestCase):
                 "iNTerest",
                 RP2Decimal("0.00000000000001"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -609,7 +593,7 @@ class TestInTransaction(unittest.TestCase):
                 "iNterest",
                 RP2Decimal("-1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -625,7 +609,7 @@ class TestInTransaction(unittest.TestCase):
                 "iNtereSt",
                 "1000",  # type: ignore
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -641,7 +625,7 @@ class TestInTransaction(unittest.TestCase):
                 "intereSt",
                 RP2Decimal("1000"),
                 RP2Decimal("0"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -657,7 +641,7 @@ class TestInTransaction(unittest.TestCase):
                 "interESt",
                 RP2Decimal("1000"),
                 RP2Decimal("-2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -673,7 +657,7 @@ class TestInTransaction(unittest.TestCase):
                 "interEst",
                 RP2Decimal("1000.0"),
                 "2.0002",  # type: ignore
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -689,7 +673,7 @@ class TestInTransaction(unittest.TestCase):
                 "inteREst",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("-20"),
+                fiat_fee=RP2Decimal("-20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -705,7 +689,7 @@ class TestInTransaction(unittest.TestCase):
                 "intEREst",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                "20",  # type: ignore
+                fiat_fee="20",  # type: ignore
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -721,7 +705,7 @@ class TestInTransaction(unittest.TestCase):
                 "inTEREst",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("-2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -737,7 +721,7 @@ class TestInTransaction(unittest.TestCase):
                 "inTERESt",
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee="2000.2",  # type: ignore
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -753,7 +737,7 @@ class TestInTransaction(unittest.TestCase):
                 "iNTERESt",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("-2020.2"),
                 internal_id=19,
@@ -769,7 +753,7 @@ class TestInTransaction(unittest.TestCase):
                 "INTERESt",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=(1, 2, 3),  # type: ignore
                 internal_id=19,
@@ -785,7 +769,7 @@ class TestInTransaction(unittest.TestCase):
                 "INTEREST",
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
@@ -802,12 +786,29 @@ class TestInTransaction(unittest.TestCase):
                 "INTeREST",
                 RP2Decimal("1000.0"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("20"),
+                fiat_fee=RP2Decimal("20"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
                 notes=[1, 2, 3],  # type: ignore
             )
+        with self.assertRaisesRegex(RP2ValueError, "both 'crypto_fee' and 'fiat_fee' are defined: only one allowed"):
+            # Bad notes
+            InTransaction(
+                self._configuration,
+                "2021-01-02T08:42:43.882Z",
+                "B1",
+                "BlockFi",
+                "Bob",
+                "INTeREST",
+                RP2Decimal("1000.0"),
+                RP2Decimal("2.0002"),
+                crypto_fee=RP2Decimal("0.02"),
+                fiat_fee=RP2Decimal("20"),
+                fiat_in_no_fee=RP2Decimal("2000.2"),
+                fiat_in_with_fee=RP2Decimal("2020.2"),
+                internal_id=19,
+            )
 
         with self.assertLogs(level="WARNING") as log:
             # Crypto in * spot price != fiat in (without fee)
@@ -820,7 +821,7 @@ class TestInTransaction(unittest.TestCase):
                 "INTerEST",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("1000"),
+                fiat_fee=RP2Decimal("1000"),
                 fiat_in_no_fee=RP2Decimal("1900.2"),
                 fiat_in_with_fee=RP2Decimal("2000.2"),
                 internal_id=19,
@@ -838,7 +839,7 @@ class TestInTransaction(unittest.TestCase):
                 "INTerESt",
                 RP2Decimal("1000"),
                 RP2Decimal("2.0002"),
-                RP2Decimal("18"),
+                fiat_fee=RP2Decimal("18"),
                 fiat_in_no_fee=RP2Decimal("2000.2"),
                 fiat_in_with_fee=RP2Decimal("2020.2"),
                 internal_id=19,
