@@ -233,7 +233,7 @@ class TestIntraTransaction(unittest.TestCase):
         self.assertNotEqual(intra_transaction, intra_transaction3)
         self.assertEqual(hash(intra_transaction), hash(intra_transaction))
         self.assertEqual(hash(intra_transaction), hash(intra_transaction2))
-        # These hashes would only be equal in case of hash collision (possible but very unlikey)
+        # These hashes would only be equal in case of hash collision (possible but very unlikely)
         self.assertNotEqual(hash(intra_transaction), hash(intra_transaction3))
 
     def test_bad_to_string(self) -> None:
@@ -276,7 +276,7 @@ class TestIntraTransaction(unittest.TestCase):
                     "BUY",
                     RP2Decimal("10000"),
                     RP2Decimal("1"),
-                    RP2Decimal("0"),
+                    fiat_fee=RP2Decimal("0"),
                     internal_id=45,
                 ),
             )
@@ -311,21 +311,6 @@ class TestIntraTransaction(unittest.TestCase):
                 RP2Decimal("1.9998"),
                 internal_id=19,
             )
-        with self.assertRaisesRegex(RP2ValueError, "Parameter 'internal_id' has non-positive value .*"):
-            # Bad internal_id
-            IntraTransaction(
-                self._configuration,
-                "2021-01-02T08:42:43.882Z",
-                "B1",
-                "Coinbase Pro",
-                "Bob",
-                "BlockFi",
-                "Alice",
-                RP2Decimal("1000.0"),
-                RP2Decimal("2.0002"),
-                RP2Decimal("1.9998"),
-                internal_id=-19,
-            )
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'internal_id' has non-integer value .*"):
             # Bad internal_id
             IntraTransaction(
