@@ -38,6 +38,9 @@ class TestODSOutputDiff(AbstractTestODSOutputDiff):  # pylint: disable=too-many-
             AbstractTestODSOutputDiff._generate(cls.output_dir, test_name="test_data", config="test_data", method=method)
             AbstractTestODSOutputDiff._generate(cls.output_dir, test_name="test_data2", config="test_data", method=method)
             AbstractTestODSOutputDiff._generate(cls.output_dir, test_name="test_data3", config="test_data", method=method)
+            AbstractTestODSOutputDiff._generate(cls.output_dir, test_name="test_data4", config="test_data4", method=method)
+            AbstractTestODSOutputDiff._generate(cls.output_dir, test_name="test_hifo", config="test_data", method=method)
+            AbstractTestODSOutputDiff._generate(cls.output_dir, test_name="test_hifo2", config="test_data", method=method)
             AbstractTestODSOutputDiff._generate(cls.output_dir, test_name="test_many_year_data", config="test_data", method=method)
             AbstractTestODSOutputDiff._generate(
                 cls.output_dir, test_name="test_data3", config="test_data", method=method, from_date=date(2019, 12, 1), to_date=date(2020, 4, 1)
@@ -100,6 +103,30 @@ class TestODSOutputDiff(AbstractTestODSOutputDiff):  # pylint: disable=too-many-
         for method in self.METHODS:
             self._compare(output_dir=self.output_dir, test_name="test_data3", method=method, output_plugin=OutputPlugins.TAX_REPORT_US)
 
+    def test_test_data4_rp2_full_report(self) -> None:
+        for method in self.METHODS:
+            self._compare(output_dir=self.output_dir, test_name="test_data4", method=method, output_plugin=OutputPlugins.RP2_FULL_REPORT)
+
+    def test_test_data4_tax_report_us(self) -> None:
+        for method in self.METHODS:
+            self._compare(output_dir=self.output_dir, test_name="test_data4", method=method, output_plugin=OutputPlugins.TAX_REPORT_US)
+
+    def test_test_hifo_rp2_full_report(self) -> None:
+        for method in self.METHODS:
+            self._compare(output_dir=self.output_dir, test_name="test_hifo", method=method, output_plugin=OutputPlugins.RP2_FULL_REPORT)
+
+    def test_test_hifo_tax_report_us(self) -> None:
+        for method in self.METHODS:
+            self._compare(output_dir=self.output_dir, test_name="test_hifo", method=method, output_plugin=OutputPlugins.TAX_REPORT_US)
+
+    def test_test_hifo2_rp2_full_report(self) -> None:
+        for method in self.METHODS:
+            self._compare(output_dir=self.output_dir, test_name="test_hifo2", method=method, output_plugin=OutputPlugins.RP2_FULL_REPORT)
+
+    def test_test_hifo2_tax_report_us(self) -> None:
+        for method in self.METHODS:
+            self._compare(output_dir=self.output_dir, test_name="test_hifo2", method=method, output_plugin=OutputPlugins.TAX_REPORT_US)
+
     def test_test_many_year_data_rp2_full_report(self) -> None:
         for method in self.METHODS:
             self._compare(output_dir=self.output_dir, test_name="test_many_year_data", method=method, output_plugin=OutputPlugins.RP2_FULL_REPORT)
